import { Channel, ClientFactory } from 'nice-grpc';
import { CreateWorkflowVersionOpts, WorkflowServiceClient } from '../../protoc/workflows';
import { ClientConfig } from '../hatchet-client/client-config';
import { Api } from '../rest';
/**
 * AdminClient is a client for interacting with the Hatchet Admin API. This allows you to configure, trigger,
 * and monitor workflows.
 * The admin client can be accessed via:
 * ```typescript
 * const hatchet = Hatchet.init()
 * const admin = hatchet.admin as AdminClient;
 *
 * // Now you can use the admin client to interact with the Hatchet Admin API
 * admin.list_workflows().then((res) => {
 *   res.rows?.forEach((row) => {
 *     console.log(row);
 *   });
 * });
 * ```
 */
export declare class AdminClient {
    config: ClientConfig;
    client: WorkflowServiceClient;
    api: Api;
    tenantId: string;
    constructor(config: ClientConfig, channel: Channel, factory: ClientFactory, api: Api, tenantId: string);
    /**
     * Creates a new workflow or updates an existing workflow. If the workflow already exists, Hatchet will automatically
     * determine if the workflow definition has changed and create a new version if necessary.
     * @param workflow a workflow definition to create
     */
    put_workflow(workflow: CreateWorkflowVersionOpts): Promise<void>;
    /**
     * Run a new instance of a workflow with the given input. This will create a new workflow run and return the ID of the
     * new run.
     * @param workflowName the name of the workflow to run
     * @param input an object containing the input to the workflow
     * @returns the ID of the new workflow run
     */
    run_workflow(workflowName: string, input: object): Promise<string>;
    /**
     * List workflows in the tenant associated with the API token.
     * @returns a list of all workflows in the tenant
     */
    list_workflows(): Promise<import("../rest/generated/data-contracts").WorkflowList>;
    /**
     * Get a workflow by its ID.
     * @param workflowId the workflow ID (**note:** this is not the same as the workflow version id)
     * @returns
     */
    get_workflow(workflowId: string): Promise<import("../rest/generated/data-contracts").Workflow>;
    /**
     * Get a workflow version.
     * @param workflowId the workflow ID
     * @param version the version of the workflow to get. If not provided, the latest version will be returned.
     * @returns the workflow version
     */
    get_workflow_version(workflowId: string, version?: string): Promise<import("../rest/generated/data-contracts").WorkflowVersion>;
    /**
     * Get a workflow run.
     * @param workflowRunId the id of the workflow run to get
     * @returns the workflow run
     */
    get_workflow_run(workflowRunId: string): Promise<import("../rest/generated/data-contracts").WorkflowRun>;
    /**
     * List workflow runs in the tenant associated with the API token.
     * @param query the query to filter the list of workflow runs
     * @returns
     */
    list_workflow_runs(query: {
        offset?: number | undefined;
        limit?: number | undefined;
        eventId?: string | undefined;
        workflowId?: string | undefined;
    }): Promise<import("../rest/generated/data-contracts").WorkflowRunList>;
    /**
     * Schedule a workflow to run at a specific time or times.
     * @param workflowId the ID of the workflow to schedule
     * @param options an object containing the schedules to set
     */
    schedule_workflow(workflowId: string, options?: {
        schedules?: Date[];
    }): void;
}
